BinaryFileFormField class

Binary file field in the multipart/form-data

Implemented types
Implementers

Constructors

BinaryFileFormField(String name, Stream<List<int>> value, {ContentType? contentType, String? filename})

Properties

contentType → ContentType?
content-type of the field
final
filename → String?
File of the file field
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the field
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Stream<List<int>>
Value of the field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
writeTo(String path) → Future<File>
Writes the contents of the file to file at path
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited