BinaryFileListFormField class

Implemented types

Properties

contentType → ContentType?
content-type of the field
no setteroverride
filename → String?
File of the file field
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the field
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Stream<List<int>>
Value of the field
no setteroverride
values → List<BinaryFileFormField>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
writeTo(String path) → Future<File>
Writes the contents of the file to file at path
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited