FileFormField<T> class abstract

Implemented types
Implementers

Constructors

FileFormField()

Properties

contentType → ContentType?
content-type of the field
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the field
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
Value of the field
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
writeTo(String path) → Future<File>

Operators

operator ==(Object other) → bool
The equality operator.
inherited