StringFormField class

String field in the multipart/form-data

Contains String value

Implemented types

Constructors

StringFormField(String name, String value, {ContentType? contentType})

Properties

contentType → ContentType?
content-type of the field
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the field
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Value of the field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited