TextFileFormField class

Text file field in the multipart/form-data

Implemented types
Implementers

Constructors

TextFileFormField(String name, Stream<String> value, {ContentType? contentType, String? filename})

Properties

contentType → ContentType?
content-type of the field
final
filename → String?
File of the file field
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the field
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Stream<String>
Value of the field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
writeTo(String path, {Encoding encoding = utf8}) → Future<File>
Writes the contents of the file to file at path
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited