UserEmail class abstract

AuthorizationUser that uses email as authenticationId and unique record id as authorizationId

Implemented types

Constructors

UserEmail()

Properties

authorizationId → String
Authorization Id is the field used to identify the logged in user in session data
no setteroverride
email → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
password → String
Secret password the user uses to authenticate.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited