WsStream class

Implemented types

Constructors

WsStream({String path = '', Map<String, String>? pathRegEx, int? statusCode, String? mimeType, String? charset = kDefaultCharset, ResponseProcessor? responseProcessor})
const

Properties

charset → String?
final
hashCode → int
The hash code for this object.
no setterinherited
methods → List<String>
Methods handled by the route
final
mimeType → String?
final
path → String
Path of the route
final
pathRegEx → Map<String, String>?
Map of regular expression matchers for specific path segment
final
responseProcessor → ResponseProcessor?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
final

Methods

cloneWith({String? path, List<String>? methods, Map<String, String>? pathRegEx, int? statusCode, String? mimeType, String? charset, ResponseProcessor? responseProcessor}) → HttpMethod
override
makeHandler(WsOnConnect onConnect) → RouteHandler
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited