QueryParams class

Class to hold query parameters

Inheritance
Implemented types

Properties

entries → Iterable<MapEntry<String, String>>
The map entries of this Map.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<String>
The keys of this Map.
no setterinherited
length → int
The number of key/value pairs in the map.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable<String>
The values of this Map.
no setterinherited

Methods

addAll(Map<String, String> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<String, String>> entries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<K2, V2>() → Map<K2, V2>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void f(String, String)) → void
Applies action to each key/value pair of the map.
inherited
get(String key, [String? defaultValue]) → String?
Retrieve a value from this map
inherited
getBool(String key, [bool? defaultValue]) → bool?
Retrieve a value from this map
inherited
getDateTime(String key, {DateTime? defaultValue}) → DateTime?
inherited
getDouble(String key, [double? defaultValue]) → double?
Retrieve a value from this map
inherited
getInt(String key, [int? defaultValue]) → int?
Retrieve a value from this map
inherited
getList(String key, [Pattern separator = ","]) → List<String>
inherited
getNum(String key, [num? defaultValue]) → num?
Retrieve a value from this map
inherited
map<K2, V2>(MapEntry<K2, V2> transform(String, String)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, String ifAbsent()) → String
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → String?
Removes key and its associated value, if present, from the map.
inherited
removeWhere(bool test(String, String)) → void
Removes all entries of this map that satisfy the given test.
inherited
retype<K2, V2>() → Map<K2, V2>
inherited
toString() → String
A string representation of this object.
update(String key, String update(String), {String ifAbsent()?}) → String
Updates the value for the provided key.
inherited
updateAll(String update(String, String)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → String?
The value for the given key, or null if key is not in the map.
inherited
operator []=(String key, String value) → void
Associates the key with the given value.
inherited