SkipResponse class

Inheritance

Constructors

SkipResponse()

Properties

body ↔ dynamic
Body of the response
getter/setter pairinherited
cookies → List<Cookie>
Cookies
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → JaguarHttpHeaders
Headers
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int
Status code of the response
getter/setter pairinherited

Methods

deleteCookie(String name, {String path = '/'}) → void
deleteCookie deletes a cookie with given name. Use path to specify the path from which the cookie has to be removed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
writeAllButBody(HttpResponse resp) → void
inherited
writeResponse(HttpResponse resp) → void
Writes body of the HTTP response from body property
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited